@@ -114,9 +114,9 @@ void CalendarIndexer::remove(const Akonadi::Collection &collection)
     }
 }
 
-void CalendarIndexer::move(const Akonadi::Item::Id &itemId,
-                           const Akonadi::Collection::Id &from,
-                           const Akonadi::Collection::Id &to)
+void CalendarIndexer::move(Akonadi::Item::Id itemId,
+                           Akonadi::Collection::Id from,
+                           Akonadi::Collection::Id to)
 {
     if (!m_db) {
         return;
